/*
 * (c) Copyright Rational Software Corporation. 2002.
 * All Rights Reserved.
 */

package newdebug;

import org.eclipse.cdt.debug.core.cdi.CDIException;
import org.eclipse.cdt.debug.core.cdi.ICDISession;
import org.eclipse.cdt.debug.mi.core.GDBDebugger;
import org.eclipse.cdt.debug.mi.core.MIException;
import org.eclipse.cdt.debug.mi.core.MISession;
import org.eclipse.cdt.debug.mi.core.cdi.Session;
import org.eclipse.cdt.debug.mi.core.command.CommandFactory;
import org.eclipse.cdt.debug.mi.core.command.MITargetSelect;
import org.eclipse.cdt.debug.mi.core.output.MIInfo;
import org.eclipse.core.resources.IFile;
import org.eclipse.debug.core.ILaunchConfiguration;

/**
 * Cygwin GDB Debugger overrides the GDB Debugger to apply the Cygwin
 * Command Factory to the MI Session.
 */
public class PalmOSGDBDebugger extends GDBDebugger {

	/* PalmOS does not have any special initialization like solib paths etc.. */
	protected void initializeLibraries(
		ILaunchConfiguration config,
		Session session)
		throws CDIException {
	}

	public ICDISession createLaunchSession(
		ILaunchConfiguration config,
		IFile exe)
		throws CDIException {
		Session session = (Session) super.createLaunchSession(config, exe);
		// For windows we need to start the inferior in a new console window
		// to separate the Inferior std{in,out,err} from gdb std{in,out,err}
		MISession mi = session.getMISession();
		try {
			CommandFactory factory = mi.getCommandFactory();
			String[] targetParams = new String[1];
			targetParams[0] = "palmos";
			MITargetSelect target = factory.createMITargetSelect(targetParams);
			mi.postCommand(target);
			MIInfo info = target.getMIInfo();
			if (info == null) {
				throw new MIException("No answer");
			}
		} catch (MIException e) {
			// We ignore this exception, for example
			// on GNU/Linux the new-console is an error.
		}
		return session;
	}
}